@@ -7,8 +7,7 @@ from urlparse import urlparse
 
 import httplib2
 
-__version__ = '0.10.0'
-debugging = True
+__version__ = '0.10.1'
 
 try:
     import jsonlib2 as json
@@ -291,13 +290,12 @@ class Design(object):
         self._id = _id
 
     def __getattr__(self, name):
-        if debugging:
-            response = self.db.http.head(self._id+'/_view/'+name+'/')
-        if not debugging or response.status == 200 or response.status == 304:
+        response = self.db.http.head(self._id+name+'/')
+        if response.status == 200 or response.status == 304:
             setattr(self, name, View(self.db, self._id+'/_view/'+name+'/'))
             return getattr(self, name)
         else:
-            raise AttributeError("No view named "+name+". "+response.body)
+            raise AttributeError("No view named "+name+". "+str(response.status))
 
 
 class TempViewException(Exception):
@@ -361,13 +359,12 @@ class Views(object):
             raise Exception(response.body)
 
     def __getattr__(self, name):
-        if debugging:
-            response = self.db.http.head(self.path+name+'/')
-        if not debugging or response.status == 200 or response.status == 304:
+        response = self.db.http.head(self.path+name+'/')
+        if response.status == 200 or response.status == 304:
             setattr(self, name, Design(self.db, '_design/'+name))
             return getattr(self, name)
         else:
-            raise AttributeError("No view named "+name)
+            raise AttributeError("No view named "+name + " "+str(response.status))
 
 
 class CouchDBException(Exception):
@@ -447,6 +444,13 @@ class Database(object):
             else:
                 yield rev["rev"]
 
+    def compaction(self):
+        """Compact database [http://wiki.apache.org/couchdb/Compaction]"""
+        response = self.http.post("_compact")
+        if response.status == 404:
+            return False
+        return True
+
     def all_ids(self):
         """List all documents ids in the database."""
         response = self.http.get("_all_docs")
